@@ -1,5 +1,5 @@
 package WWW::AzimuthAero::Mock;
-$WWW::AzimuthAero::Mock::VERSION = '0.2';
+$WWW::AzimuthAero::Mock::VERSION = '0.3';
 
 # ABSTRACT: additional subroutines for unit testing
 
@@ -26,6 +26,7 @@ sub filename {
     return 't/ua_mock.json';
 }
 
+
 sub generate {
     my $self      = shift;
     my $mock_data = $self->mock_data->{get};
@@ -62,7 +63,7 @@ WWW::AzimuthAero::Mock - additional subroutines for unit testing
 
 =head1 VERSION
 
-version 0.2
+version 0.3
 
 =head1 SYNOPSIS
 
@@ -72,10 +73,14 @@ version 0.2
 
     Some helpers to generate mocks
 
-=head1 mock_data
+=head2 mock_data
 
 Return data that is used for mock at unit tests
 
+=head2 generate
+
+Generate json mock data
+
 =head1 AUTHOR
 
 Pavel Serikov <pavelsr@cpan.org>
