@@ -1,5 +1,5 @@
 package WWW::AzimuthAero::RouteMap;
-$WWW::AzimuthAero::RouteMap::VERSION = '0.2';
+$WWW::AzimuthAero::RouteMap::VERSION = '0.3';
 
 # ABSTRACT: Route map representation
 
@@ -52,7 +52,7 @@ sub get_iata_by_azo {
 
 
 sub route_map_iata {
-    my ($self) = @_;
+    my ( $self, @cities ) = @_;
     my $res = {};
     while ( my ( $azo_code, $data ) = each( %{ $self->raw } ) ) {
         $res->{ $self->get_iata_by_azo($azo_code) } = [
@@ -61,6 +61,15 @@ sub route_map_iata {
               keys %{ $self->raw->{$azo_code}{ROUTES} }
         ];
     }
+
+    if (@cities) {
+        use experimental 'smartmatch';
+        while ( my ( $k, $v ) = each(%$res) ) {
+            delete $res->{$k} unless ( $k ~~ @cities );
+            @$v = grep { $_ ~~ @cities } @$v;
+        }
+    }
+
     return $res;
 }
 
@@ -148,34 +157,35 @@ WWW::AzimuthAero::RouteMap - Route map representation
 
 =head1 VERSION
 
-version 0.2
+version 0.3
 
 =head1 SYNOPSIS
 
-    my $az = WWW::AzimuthAero->new();
-    $az->get( from => 'ROV', to => 'LED', date => '14.06.2019' ); 
-    $az->get_lowest_fares( from => 'ROV', to => 'LED', max_date => '14.08.2019' )->print;
+    my $rm = WWW::AzimuthAero::RouteMap->new($route_map_raw_hash);
+    $rm->route_map_iata()
 
 =head1 DESCRIPTION
 
     https://azimuth.aero/ru/about/flight-map
 
-=head1 new
+=head1 METHODS
+
+=head2 new
 
     my $rm = WWW::AzimuthAero::RouteMap->new($route_map_raw_hash);
 
-=head1 new
+=head2 new
 
     Return hash with original route map parsed from site
 
-=head1 all_cities
+=head2 all_cities
 
 Return sorted list of city names in route map
 
     print $rm->all_cities()    
     print join(',' map { "\'". $_ ."\'" } $rm->all_cities() ); # for json array
 
-=head1 get
+=head2 get
 
 Universal accessor function for route map, wrapper under L<WWW::AzimuthAero::RouteMap/all_cities>
 
@@ -186,7 +196,7 @@ Examples:
     $rm->get('IATA', 'NAME', 'Ростов-на-Дону')
     $rm->get('IATA', 'AZO', 'РОВ')
 
-=head1 route_map_iata
+=head2 route_map_iata
 
 Return hash with IATA route map
 
@@ -200,7 +210,13 @@ Amount of all routes
 
     perl -Ilib -MWWW::AzimuthAero -e 'my $x = WWW::AzimuthAero->new->route_map->route_map_iata; my $i = 0; $i+= scalar @$_ for values %$x; print $i;'
 
-=head1 neighbor_airports
+Params:
+
+    cities 
+
+    perl -Ilib -MWWW::AzimuthAero -MData::Dumper -e 'my $x = WWW::AzimuthAero->new->route_map->route_map_iata('ROV', 'LED', 'KRR'); warn Dumper $x;'
+
+=head2 neighbor_airports
 
 Return hash of airports that are no more than 4 hours by train from each other 
 
@@ -218,13 +234,13 @@ When you set new city please check it's availability at L<WWW::AzimuthAero::Rout
 
 TO-DO: check correctness with Yandex Maps API and RZD API
 
-=head1 get_neighbor_airports_iata
+=head2 get_neighbor_airports_iata
 
 Return list of IATA codes of neighbor airports based on L<WWW::AzimuthAero::RouteMap/neighbor_airports>
 
     $rm->get_neighbor_airports_iata('LED') # ( 'PKV' )
 
-=head1 transfer_routes
+=head2 transfer_routes
 
 Convert route map to L<Graph> object and return ARRAYref of routes with one transfer maximum
 
